"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DraggableList = exports.DraggableListItem = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _Divider = require("../Divider");

var _Icon = require("../Icon");

var _designparams = require("../designparams");

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var DraggableItem = _styledComponents.default.div.withConfig({
  displayName: "DraggableList__DraggableItem",
  componentId: "fdmv69-0"
})(["display:flex;align-items:center;justify-content:space-between;width:100%;height:", ";"], _designparams.componentSize.large);

var DraggableHandle = _styledComponents.default.div.withConfig({
  displayName: "DraggableList__DraggableHandle",
  componentId: "fdmv69-1"
})(["color:", ";cursor:move;"], _ref => {
  var {
    theme
  } = _ref;
  return theme.color.element01();
});

var DragHandleIcon = () => /*#__PURE__*/_react.default.createElement("svg", {
  viewBox: "0 0 24 24",
  width: "1em",
  height: "1em"
}, /*#__PURE__*/_react.default.createElement("path", {
  d: "m20 9h-16v2h16v-2zm-16 6h16v-2h-16v2z"
}));

var DraggableListItem = _styledComponents.default.div.withConfig({
  displayName: "DraggableList__DraggableListItem",
  componentId: "fdmv69-2"
})(["display:flex;height:100%;flex-grow:1;align-items:center;"]);
/**
 * Draggable list
 *
 * A list where the items can be dragged through a drag handler
 * rendered on the right side of the list items.
 */


exports.DraggableListItem = DraggableListItem;

var DraggableList = _ref2 => {
  var {
    children,
    onChange
  } = _ref2,
      props = _objectWithoutProperties(_ref2, ["children", "onChange"]);

  var childElements = (0, _react.useMemo)(() => _react.default.Children.toArray(children), [children]);
  var locked = (0, _react.useMemo)(() => childElements.map(_utils.isElementDisabled), [childElements]);
  var elementRange = (0, _react.useMemo)(() => (0, _utils.range)(childElements.length), [childElements]);
  var [order, setOrder] = (0, _react.useState)(elementRange);
  (0, _react.useLayoutEffect)(() => setOrder(elementRange), [elementRange, childElements.length]);
  var dragIndexRef = (0, _react.useRef)();
  var dropIndexRef = (0, _react.useRef)();
  var onDragStart = (0, _react.useCallback)(e => {
    // Needed for Firefox
    // You need to set some data in the dataTransfer member
    // of the event when the drag start in Firefox
    e.dataTransfer.setData('text', '');
    dragIndexRef.current = Number(e.currentTarget.dataset.index);
  }, []);
  var onDragOver = (0, _react.useCallback)(e => {
    var dragIndex = dragIndexRef.current;

    if (dragIndex === undefined) {
      return;
    } // Only re-order elements if we're dragging over a new
    // item in the list to prevent spurious re-renders.


    var dropIndex = Number(e.currentTarget.dataset.index);

    if (dropIndex !== dropIndexRef.current) {
      var _dropIndexRef$current;

      dropIndexRef.current = dropIndex;
      setOrder((0, _utils.move)(elementRange, locked, dragIndex, (_dropIndexRef$current = dropIndexRef.current) !== null && _dropIndexRef$current !== void 0 ? _dropIndexRef$current : 0));
    }
  }, [elementRange, locked]);
  var onDragEnd = (0, _react.useCallback)(() => {
    dragIndexRef.current = undefined;
    dropIndexRef.current = undefined;
    onChange(order);
  }, [order, onChange]);
  var onGrabHandle = (0, _react.useCallback)(e => {
    if (e.currentTarget.parentElement !== null) {
      e.currentTarget.parentElement.setAttribute('draggable', 'true');
    }
  }, []);
  var onReleaseHandle = (0, _react.useCallback)(e => {
    if (e.currentTarget.parentElement !== null) {
      e.currentTarget.parentElement.setAttribute('draggable', 'false');
    }
  }, []);
  return /*#__PURE__*/_react.default.createElement("div", props, order.map((childIndex, index) => {
    var el = childElements[childIndex];
    var isLocked = locked[childIndex];
    return /*#__PURE__*/_react.default.createElement("div", {
      key: index
    }, /*#__PURE__*/_react.default.createElement(DraggableItem, {
      onDragStart: onDragStart,
      onDragOver: isLocked ? undefined : onDragOver,
      onDragEnd: onDragEnd,
      "data-index": index,
      style: {
        opacity: childIndex === dragIndexRef.current ? 0 : undefined
      }
    }, el, isLocked ? null : /*#__PURE__*/_react.default.createElement(DraggableHandle, {
      onMouseDown: onGrabHandle,
      onMouseUp: onReleaseHandle
    }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
      icon: DragHandleIcon
    }))), /*#__PURE__*/_react.default.createElement(_Divider.Divider, null));
  }));
};

exports.DraggableList = DraggableList;