"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TabBase = TabBase;
exports.Tab = Tab;
exports.VerticalTab = VerticalTab;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _Icon = require("../Icon");

var _designparams = require("../designparams");

var _Typography = require("../Typography");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// Constant size for Tab
var TAB_HEIGHT = '40px';
var MARKER_THICKNESS = '4px';
var FLEX_DIRECTION = {
  top: 'column-reverse',
  right: 'column-reverse',
  bottom: 'column-reverse',
  left: 'column-reverse'
};
/**
 * Tab container primitive
 */

var TabBaseContainer = _styledComponents.default.div.withConfig({
  displayName: "Tab__TabBaseContainer",
  componentId: "sc-14ckgxq-0"
})(["position:relative;display:flex;flex-direction:", ";height:", ";box-sizing:border-box;padding:", ";overflow:hidden;max-width:100%;user-select:none;color:", ";fill:", ";background-color:", ";opacity:", ";cursor:pointer;", ""], _ref => {
  var {
    markerOffset
  } = _ref;
  return FLEX_DIRECTION[markerOffset];
}, TAB_HEIGHT, _ref2 => {
  var {
    markerOffset
  } = _ref2;
  return markerOffset === 'left' || markerOffset === 'right' ? "0 ".concat(MARKER_THICKNESS) : "".concat(MARKER_THICKNESS, " 0");
}, _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.color.text02();
}, _ref4 => {
  var {
    theme
  } = _ref4;
  return theme.color.element11();
}, _ref5 => {
  var {
    theme
  } = _ref5;
  return theme.color.background00();
}, _ref6 => {
  var {
    disabled
  } = _ref6;
  return disabled ? _designparams.opacity[48] : undefined;
}, _ref7 => {
  var {
    theme,
    selected,
    disabled
  } = _ref7;

  if (!selected && !disabled) {
    return (0, _styledComponents.css)(["&:hover{background-color:", ";}"], theme.color.background02());
  }

  if (selected) {
    return (0, _styledComponents.css)(["color:", ";fill:", ";background-color:", ";"], theme.color.elementPrimary(), theme.color.elementPrimary(), theme.color.backgroundPrimary());
  }
});
/**
 * Tab marker primitive
 */


// Renders a marker indicating that the tab is selected
var TabBaseMarker = _styledComponents.default.div.withConfig({
  displayName: "Tab__TabBaseMarker",
  componentId: "sc-14ckgxq-1"
})(["content:' ';position:absolute;flex:none;background-color:", ";transition:all 500ms cubic-bezier(0.57,0.67,0.015,1.005);", ""], _ref8 => {
  var {
    theme
  } = _ref8;
  return theme.color.elementAccent();
}, _ref9 => {
  var {
    offset,
    selected
  } = _ref9;
  return offset === 'left' || offset === 'right' ? (0, _styledComponents.css)(["width:", ";height:100%;", ":0;transform:", ";"], MARKER_THICKNESS, offset, selected ? 'scaleY(1)' : 'scaleY(0)') : (0, _styledComponents.css)(["height:", ";width:100%;", ":0;transform:", ";"], MARKER_THICKNESS, offset, selected ? 'scaleX(1)' : 'scaleX(0)');
});
/**
 * Tab contents primitive
 */


var TabBaseContents = _styledComponents.default.div.withConfig({
  displayName: "Tab__TabBaseContents",
  componentId: "sc-14ckgxq-2"
})(["width:100%;height:100%;overflow:hidden;"]);
/**
 *
 * Tab base
 *
 * A tab that is just a container for some content,
 * no icon/text is assumed and it's up to the user
 * to generate it. Use this if you need custom layout
 * for content inside the tab.
 *
 */


function TabBase(_ref10) {
  var {
    id,
    selected,
    disabled = false,
    onSelect,
    markerOffset = 'right',
    children
  } = _ref10,
      props = _objectWithoutProperties(_ref10, ["id", "selected", "disabled", "onSelect", "markerOffset", "children"]);

  var onClick = (0, _react.useCallback)(() => {
    if (selected || disabled) {
      return;
    }

    onSelect(id);
  }, [selected, disabled, id, onSelect]);
  return /*#__PURE__*/_react.default.createElement(TabBaseContainer, _extends({
    disabled: disabled,
    onClick: onClick,
    selected: selected,
    markerOffset: markerOffset
  }, props), /*#__PURE__*/_react.default.createElement(TabBaseMarker, {
    offset: markerOffset,
    selected: selected
  }), /*#__PURE__*/_react.default.createElement(TabBaseContents, null, children));
}
/**
 *
 * Tab
 *
 * Tab base + quick setting of optional icon + label,
 * centered in the middle of the tab.
 * Use this if you need a default look for the tab
 * and only need icon/label inside the tab.
 *
 * There are two main components:
 *  - Tab (horizontal, marker top or bottom)
 *  - VerticalTab (vertical, marker left or right)
 *
 */

/**
 * Tab contents icon primitive
 */


var TabContentsIcon = (0, _styledComponents.default)(_Icon.Icon).withConfig({
  displayName: "Tab__TabContentsIcon",
  componentId: "sc-14ckgxq-3"
})(["flex:none;fill:inherit;"]);
/**
 * Tab contents label primitive
 */

var TabContentsLabel = _styledComponents.default.div.withConfig({
  displayName: "Tab__TabContentsLabel",
  componentId: "sc-14ckgxq-4"
})(["margin-left:", ";max-width:100%;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;pointer-events:none;color:inherit;font-weight:", ";"], _ref11 => {
  var {
    centered
  } = _ref11;
  return centered === true ? '0' : _designparams.spacing.medium;
}, _ref12 => {
  var {
    selected
  } = _ref12;
  return selected === true ? '600' : undefined;
});
/**
 * Tab contents primitive
 */


var TabContents = _styledComponents.default.div.withConfig({
  displayName: "Tab__TabContents",
  componentId: "sc-14ckgxq-5"
})(["height:100%;display:flex;align-items:center;justify-content:center;flex-grow:1;overflow:hidden;padding:0 ", ";"], _designparams.spacing.medium);
/**
 * Tab primitive
 */


function InternalTab(_ref13) {
  var {
    id,
    selected = false,
    disabled = false,
    icon,
    onSelect,
    markerOffset,
    label
  } = _ref13,
      props = _objectWithoutProperties(_ref13, ["id", "selected", "disabled", "icon", "onSelect", "markerOffset", "label"]);

  return /*#__PURE__*/_react.default.createElement(TabBase, _extends({
    id: id,
    disabled: disabled,
    onSelect: onSelect,
    selected: selected,
    markerOffset: markerOffset
  }, props), /*#__PURE__*/_react.default.createElement(TabContents, null, icon !== undefined ? /*#__PURE__*/_react.default.createElement(TabContentsIcon, {
    icon: icon
  }) : null, /*#__PURE__*/_react.default.createElement(TabContentsLabel, {
    selected: selected,
    centered: icon === undefined
  }, /*#__PURE__*/_react.default.createElement(_Typography.Typography, {
    variant: "navigation-label"
  }, label))));
}
/**
 * Tab
 */


function Tab(_ref14) {
  var {
    markerOffset = 'bottom'
  } = _ref14,
      props = _objectWithoutProperties(_ref14, ["markerOffset"]);

  return /*#__PURE__*/_react.default.createElement(InternalTab, _extends({}, props, {
    markerOffset: markerOffset
  }));
}
/**
 * Vertical tab
 */


function VerticalTab(_ref15) {
  var {
    markerOffset = 'right'
  } = _ref15,
      props = _objectWithoutProperties(_ref15, ["markerOffset"]);

  return /*#__PURE__*/_react.default.createElement(InternalTab, _extends({}, props, {
    markerOffset: markerOffset
  }));
}